## ----echo = FALSE-----------------------
## no idea why dplyr doesn't remember this
select <- dplyr::select


## ----mot, fig.cap = "(ref:mot)", out.width = "80%", echo = FALSE, fig.align = "center"----
knitr::include_graphics("cc_figure/MOT.png", dpi = 1000)


## ---- message = FALSE-------------------
data("df_pupil_pilot")
df_pupil_pilot$p_size %>% summary()


## ---------------------------------------
qnorm(c(.025, .975), mean = 1000, sd = 500)


## ---------------------------------------
c(
  qtnorm(.025, mean = 0, sd = 1000, a = 0),
  qtnorm(.975, mean = 0, sd = 1000, a = 0)
)


## ---------------------------------------
samples <- rtnorm(20000, mean = 0, sd = 1000, a = 0)
c(mean = mean(samples), sd = sd(samples))


## ---------------------------------------
c(qnorm(.025, mean = 0, sd = 100), qnorm(.975, mean = 0, sd = 100))


## **Truncated distributions**


## ---------------------------------------
dnorm(1, mean = 0) * 2 == dtnorm(1, mean = 0, a = 0)


## ---------------------------------------
mean_n_ab <- function(mu = 0, sigma = 1, a = -Inf, b = Inf) {
  alpha <- (a - mu) / sigma
  beta <- (b - mu) / sigma
  mu + sigma * (dnorm(alpha) - dnorm(beta)) /
    (pnorm(beta) - pnorm(alpha))
}


## ---------------------------------------
mean_n_ab(mu = 0, sigma = 1000, a = 0)


## ---------------------------------------
mean(rtnorm(20000, mean = 0, sd = 1000, a = 0))


## ---- message = FALSE-------------------
data("df_pupil")
(df_pupil <- df_pupil %>%
  mutate(c_load = load - mean(load)))


## ----fitpupil, message = FALSE, results = "hide"----
fit_pupil <- brm(p_size ~ 1 + c_load,
  data = df_pupil,
  family = gaussian(),
  prior = c(
    prior(normal(1000, 500), class = Intercept),
    prior(normal(0, 1000), class = sigma),
    prior(normal(0, 100), class = b, coef = c_load)
  )
)


## ----posteriorsloadpupilsize,fig.cap="(ref:posteriorsloadpupilsize)"----
plot(fit_pupil)


## ---- eval = FALSE----------------------
## fit_pupil

## ---- echo = FALSE----------------------
short_summary(fit_pupil)


## **Intercepts in `brms`**


## ----fitpupil2, message = FALSE, results = "hide"----
prior_nc <- c(
  prior(normal(800, 200), class = b, coef = Intercept),
  prior(normal(0, 1000), class = sigma),
  prior(normal(0, 100), class = b, coef = load)
)

fit_pupil_non_centered <- brm(p_size ~ 0 + Intercept + load,
  data = df_pupil,
  family = gaussian(),
  prior = prior_nc
)


## ----centered-non-centered, echo = FALSE, fig.cap ="(ref:centered-non-centered)", fig.pos = "H", out.extra = ''----
intercept_nc <- posterior_summary(fit_pupil_non_centered, variable = "b_Intercept")[, "Estimate"]
slope_nc <- posterior_summary(fit_pupil_non_centered, variable = "b_load")[, "Estimate"]
p_nc <- plot(conditional_effects(fit_pupil_non_centered), points = TRUE, plot = FALSE)[[1]] +
  annotate("point", x = 0, y = intercept_nc, shape = 1, size = 7) +
  annotate("segment", x = 0, y = intercept_nc, xend = 1, yend = intercept_nc, linetype = "dotted") +
  annotate("segment", x = 1, y = intercept_nc, xend = 1, yend = intercept_nc + slope_nc, linetype = "dashed", arrow = arrow(length = unit(.2, "cm"))) +
  ggtitle("Non-centered predictors")

intercept_c <- posterior_summary(fit_pupil, variable = "b_Intercept")[, "Estimate"]
slope_c <- posterior_summary(fit_pupil, variable = "b_c_load")[, "Estimate"]
p_c <- plot(conditional_effects(fit_pupil), points = TRUE, plot = FALSE)[[1]] +
  annotate("point", x = 0, y = intercept_c, shape = 1, size = 7) +
  annotate("segment", x = 0, y = intercept_c, xend = 1, yend = intercept_c, linetype = "dotted") +
  annotate("segment", x = 1, y = intercept_c, xend = 1, yend = intercept_c + slope_c, linetype = "dashed", arrow = arrow(length = unit(.2, "cm"))) +
  ggtitle("Centered predictors")
gridExtra::grid.arrange(p_nc, p_c, nrow = 1)


## ---- eval = TRUE-----------------------
posterior_summary(fit_pupil_non_centered,
                  variable = c("b_Intercept", "b_load"))


## ---- eval = FALSE----------------------
## fit_pupil_wrong <- brm(p_size ~ 1 + load,
##   data = df_pupil,
##   family = gaussian(),
##   prior = prior_nc
## )


## ---- echo = FALSE----------------------
mean_load <- posterior_summary(fit_pupil, variable = "b_c_load")[, "Estimate"] %>%
  round(2)
load_l <- posterior_summary(fit_pupil, variable = "b_c_load")[, "Q2.5"] %>%
  round(2)
load_h <- posterior_summary(fit_pupil, variable = "b_c_load")[, "Q97.5"] %>%
  round(2)


## ---------------------------------------
mean(as_draws_df(fit_pupil)$b_c_load > 0)


## ----postpreddens, fig.cap ="(ref:postpreddens)" , message= FALSE, fig.height = 2, fig.show = "hold",  fig.align='center'----
for (l in 0:4) {
  df_sub_pupil <- filter(df_pupil, load == l)
  p <- pp_check(fit_pupil,
    type = "dens_overlay",
    ndraws = 100,
    newdata = df_sub_pupil
  ) +
    geom_point(data = df_sub_pupil, aes(x = p_size, y = 0.0001)) +
    ggtitle(paste("load: ", l)) +
    coord_cartesian(xlim = c(400, 1000))
  print(p)
}


## ----postpredmean, fig.cap ="(ref:postpredmean)", message= FALSE, fig.height = 2, fig.show = "hold", fig.align='center'----
for (l in 0:4) {
  df_sub_pupil <- filter(df_pupil, load == l)
  p <- pp_check(fit_pupil,
    type = "stat",
    ndraws = 1000,
    newdata = df_sub_pupil,
    stat = "mean"
  ) +
    geom_point(data = df_sub_pupil, aes(x = p_size, y = 0.0001)) +
    ggtitle(paste("load: ", l)) +
    coord_cartesian(xlim = c(400, 1000))
  print(p)
}


## ---------------------------------------
df_spacebar <- df_spacebar %>%
  mutate(c_trial = trial - mean(trial))


## ---- message = FALSE-------------------
df_spacebar_ref <- df_spacebar %>%
  mutate(rt = runif(n(), 0, 10000))
fit_prior_press_trial <- brm(rt ~ 1 + c_trial,
  data = df_spacebar_ref,
  family = lognormal(),
  prior = c(
    prior(normal(6, 1.5), class = Intercept),
    prior(normal(0, 1), class = sigma),
    prior(normal(0, 1), class = b, coef = c_trial)
  ),
  sample_prior = "only",
  control = list(adapt_delta = .9),
  iter = 3000
)


## ----priorbeta,fig.cap="(ref:priorbeta)", message = FALSE,fig.height = 2----
median_effect <- function(x) {
  median(x - lag(x), na.rm = TRUE)
}
pp_check(fit_prior_press_trial, type = "stat", stat = "median_effect")


## ----priorbeta2,fig.cap="(ref:priorbeta2)", message = FALSE, echo = FALSE, fig.height = 2----
df_spacebar_ref <- df_spacebar %>%
  mutate(rt = runif(n(), 0, 10000))
fit_prior_press_trial <- brm(rt ~ 1 + c_trial,
  data = df_spacebar_ref,
  family = lognormal(),
  prior = c(
    prior(normal(6, 1.5), class = Intercept),
    prior(normal(0, 1), class = sigma),
    prior(normal(0, .01), class = b, coef = c_trial)
  ),
  sample_prior = "only",
  control = list(adapt_delta = .95)
)
pp_check(fit_prior_press_trial, type = "stat", 
         stat = "median_effect")


## **Understanding the Log-normal likelihood**


## ----logexp, fig.cap="(ref:logexp)", echo = FALSE, fig.pos = "H", out.extra = ''----
df_a <- tibble(
Intercept = seq(.1, 15, .01),
beta = .01,
ms = exp(Intercept + beta) - exp(Intercept)
)
ggplot(df_a, aes(x = Intercept, y = ms)) +
geom_line() +
scale_y_continuous("Difference in response times between adjacent trials \n") +
scale_x_continuous("Intercept value") +
ylab("(A)")


## ----expgd, fig.cap="(ref:expgd)", echo = FALSE, fig.pos = "H", out.extra = ''----
N <- 300
df_dg <- tibble(
  n = rep(seq(1, N, 5), 2),
  Intercept = 6,
  beta = rep(c(-.01, .01), length(n) / 2),
  ms = exp(Intercept + n * beta),
  type = rep(c("(A) Exponential decay", "(B) Exponential growth"), length(n) / 2)
)


ggplot(df_dg, aes(x = n, y = ms)) +
  geom_point() +
  scale_x_continuous("Trial number") +
  scale_y_continuous("response times  in milliseconds \n") +
  facet_grid(type ~ ., scales = "free")


## ----expgd2, fig.cap="(ref:expgd2)", echo = FALSE, fig.pos = "H",out.extra =''----
N <- 300
df_dg <- tibble(
  n = rep(seq(1, N, 5), 2),
  Intercept = 6,
  beta = rep(c(-.01, .01), length(n) / 2),
  ms = exp(Intercept + log(n) * beta),
  type = rep(c("(A) Exponential decay", "(B) Exponential growth"), length(n) / 2)
)

ggplot(df_dg, aes(x = n, y = ms)) +
  geom_point() +
  scale_x_continuous("Trial number") +
  scale_y_continuous("response times  in milliseconds \n") +
  facet_grid(type ~ ., scales = "free")


## ----  message = FALSE------------------
fit_press_trial <- brm(rt ~ 1 + c_trial,
  data = df_spacebar,
  family = lognormal(),
  prior = c(
    prior(normal(6, 1.5), class = Intercept),
    prior(normal(0, 1), class = sigma),
    prior(normal(0, .01), class = b, coef = c_trial)
  )
)


## ---------------------------------------
posterior_summary(fit_press_trial)[, c("Estimate", "Q2.5", "Q97.5")]


## ----posteriorsfitpresstrial,fig.cap="Posterior distributions of the model of the effect of trial on button-pressing."----
plot(fit_press_trial)


## ---- echo=FALSE, results="hide"--------
alpha_samples <- as_draws_df(fit_press_trial)$b_Intercept
beta_samples <- as_draws_df(fit_press_trial)$b_c_trial

beta_ms <- exp(alpha_samples) - exp(alpha_samples - beta_samples)

beta_msmean <- round(mean(beta_ms), 5)
beta_mslow <- round(quantile(beta_ms, prob = 0.025), 5)
beta_mshigh <- round(quantile(beta_ms, prob = 0.975), 5)

beta_mean <- round(mean(beta_samples), 5) %>% format()
beta_low <- round(quantile(beta_samples, prob = 0.025), 5) %>% format()
beta_high <- round(quantile(beta_samples, prob = 0.975), 5) %>% format()


## ---------------------------------------
alpha_samples <- as_draws_df(fit_press_trial)$b_Intercept
beta_samples <- as_draws_df(fit_press_trial)$b_c_trial
effect_middle_ms <- exp(alpha_samples) -
  exp(alpha_samples - 1 * beta_samples)
## ms effect in the middle of the expt
## (mean trial vs. mean trial - 1)
c(
  mean = mean(effect_middle_ms),
  quantile(effect_middle_ms, c(0.025, 0.975))
)


## ---------------------------------------
first_trial <- min(df_spacebar$c_trial)
second_trial <- min(df_spacebar$c_trial) + 1
effect_beginning_ms <-
  exp(alpha_samples + second_trial * beta_samples) -
  exp(alpha_samples + first_trial * beta_samples)
## ms effect from first to second trial:
c(
  mean = mean(effect_beginning_ms),
  quantile(effect_beginning_ms, c(0.025, 0.975))
)


## ----oberauer, fig.cap = "(ref:oberauer)", fig.height =5, echo = FALSE, out.width = "100%"----
knitr::include_graphics("cc_figure/fig1_oberauer_2019_modified.png")


## ----  message = FALSE, warning = FALSE----
data("df_recall")
df_recall <- df_recall %>%
  mutate(c_set_size = set_size - mean(set_size))
# Set sizes in the data set:
df_recall$set_size %>%
  unique() %>% sort()
# Trials by set size
df_recall %>%
  group_by(set_size) %>%
  count()


## ---------------------------------------
df_recall


## ---------------------------------------
rbern(10, prob = 0.5)


## ----logisticfun, fig.cap = "The logit and inverse logit (logistic) function." ,echo = FALSE,warning=FALSE----
x <- seq(0.001, 0.999, by = 0.001)
y <- log(x / (1 - x))
logistic_dat <- data.frame(theta = x, eta = y)

p1 <- qplot(logistic_dat$theta, logistic_dat$eta, geom = "line") + xlab(expression(theta)) + ylab(expression(eta)) + ggtitle("The logit link") +
  annotate("text",
    x = 0.3, y = 4,
    label = expression(paste(eta, "=", g(theta))), parse = TRUE, size = 8
  )


p2 <- qplot(logistic_dat$eta, logistic_dat$theta, geom = "line") + xlab(expression(eta)) + ylab(expression(theta)) + ggtitle("The inverse logit link (logistic)") + annotate("text",
  x = -3.5, y = 0.80,
  label = expression(paste(theta, "=", g^-1, (eta))), parse = TRUE, size = 8
)

gridExtra::grid.arrange(p1, p2, ncol = 2)

# ggplot(tibble(x=c(-5, 5)), aes(x)) +
#    stat_function(fun = plogis) +
#    ylab("Probability")+
#    xlab("x (Log-odds)")


## ----logoddspriorsf, fig.cap= "(ref:logoddspriorsf)",fig.show='hold', out.width = "45%", fig.width =3, fig.height =3----
samples_logodds <- tibble(alpha = rnorm(100000, 0, 4))
samples_prob <- tibble(p = plogis(rnorm(100000, 0, 4)))
ggplot(samples_logodds, aes(alpha)) +
  geom_density()
ggplot(samples_prob, aes(p)) +
  geom_density()


## ----logoddspriorsf2, fig.cap= "(ref:logoddspriorsf2)",fig.show='hold', echo=FALSE, out.width = "45%", fig.width =3, fig.height =3----
samples_logodds <- tibble(alpha = rnorm(100000, 0, 1.5))
samples_prob <- tibble(p = plogis(rnorm(100000, 0, 1.5)))
ggplot(samples_logodds, aes(alpha)) +
  geom_density()
ggplot(samples_prob, aes(p)) +
  geom_density()


## **Prior predictive checks in R**


## ---------------------------------------
logistic_model_pred <- function(alpha_samples,
                                beta_samples,
                                set_size,
                                N_obs) {
  map2_dfr(alpha_samples, beta_samples,
    function(alpha, beta) {
      tibble(
        set_size = set_size,
        # center size:
        c_set_size = set_size - mean(set_size),
        # change the likelihood:
        # Notice the use of a link function
        # for alpha and beta
        theta = plogis(alpha + c_set_size * beta),
        correct_pred = rbernoulli(N_obs, p = theta)
      )
    },
    .id = "iter"
  ) %>%
    # .id is always a string and needs
    # to be converted to a number
    mutate(iter = as.numeric(iter))
}


## ---------------------------------------
N_obs <- 800
set_size <- rep(c(2, 4, 6, 8), 200)


## ---------------------------------------
alpha_samples <- rnorm(1000, 0, 1.5)
sds_beta <- c(1, 0.5, 0.1, 0.01, 0.001)
prior_pred <- map_dfr(sds_beta, function(sd) {
  beta_samples <- rnorm(1000, 0, sd)
  logistic_model_pred(
    alpha_samples = alpha_samples,
    beta_samples = beta_samples,
    set_size = set_size,
    N_obs = N_obs
  ) %>%
    mutate(prior_beta_sd = sd)
})


## ---- message = FALSE-------------------
mean_accuracy <-
  prior_pred %>%
  group_by(prior_beta_sd, iter, set_size) %>%
  summarize(accuracy = mean(correct_pred)) %>%
  mutate(prior = paste0("Normal(0, ", prior_beta_sd, ")"))


## ----priors4betacode, eval = FALSE------
## mean_accuracy %>%
##   ggplot(aes(accuracy)) +
##   geom_histogram() +
##   facet_grid(set_size ~ prior) +
##   scale_x_continuous(breaks = c(0, .5, 1))


## ---------------------------------------
diff_accuracy <- mean_accuracy %>%
  arrange(set_size) %>%
  group_by(iter, prior_beta_sd) %>%
  mutate(diff_accuracy = accuracy - lag(accuracy)) %>%
  mutate(diffsize = paste(set_size, "-", lag(set_size))) %>%
  filter(set_size > 2)


## ----priors4beta2code, eval = FALSE-----
## diff_accuracy %>%
##   ggplot(aes(diff_accuracy)) +
##   geom_histogram() +
##   facet_grid(diffsize ~ prior) +
##   scale_x_continuous(breaks = c(-.5, 0, .5))


## ----priors4beta, fig.cap="(ref:priors4beta)", message = FALSE, echo = FALSE, eval = TRUE----
mean_accuracy %>%
  ggplot(aes(accuracy)) +
  geom_histogram() +
  facet_grid(set_size ~ prior) +
  scale_x_continuous(breaks = c(0, .5, 1))


## ----priors4beta2,fig.cap="(ref:priors4beta2)", message = FALSE, echo = FALSE, eval = TRUE----
diff_accuracy %>%
  ggplot(aes(diff_accuracy)) +
  geom_histogram() +
  facet_grid(diffsize ~ prior) +
  scale_x_continuous(breaks = c(-.5, 0, .5))


## ----  message = FALSE------------------
fit_recall <- brm(correct ~ 1 + c_set_size,
  data = df_recall,
  family = bernoulli(link = logit),
  prior = c(
    prior(normal(0, 1.5), class = Intercept),
    prior(normal(0, .1), class = b, coef = c_set_size)
  )
)


## ---------------------------------------
posterior_summary(fit_recall, variable = c("b_Intercept", "b_c_set_size"))


## ----posteriorsfitrecall,  fig.cap="(ref:posteriorsfitrecall)"----
plot(fit_recall)


## ---- echo=FALSE, results="hide"--------
alpha_samples <- as_draws_df(fit_recall)$b_Intercept
beta_samples <- as_draws_df(fit_recall)$b_c_set_size
beta_mean <- round(mean(beta_samples), 5)
beta_low <- round(quantile(beta_samples, prob = 0.025), 5)
beta_high <- round(quantile(beta_samples, prob = 0.975), 5)


## ---------------------------------------
alpha_samples <- as_draws_df(fit_recall)$b_Intercept
av_accuracy <- plogis(alpha_samples)
c(mean = mean(av_accuracy), quantile(av_accuracy, c(0.025, 0.975)))


## ---------------------------------------
beta_samples <- as_draws_df(fit_recall)$b_c_set_size
effect_middle <- plogis(alpha_samples) -
  plogis(alpha_samples - beta_samples)
c(mean = mean(effect_middle), quantile(effect_middle, 
                                       c(0.025, 0.975)))


## ---------------------------------------
effect_4m2 <-
  plogis(alpha_samples + 
           (4 - mean(df_recall$set_size)) * beta_samples) -
  plogis(alpha_samples + 
           (2 - mean(df_recall$set_size)) * beta_samples)
c(mean = mean(effect_4m2), 
  quantile(effect_4m2, c(0.025, 0.975)))


## ----postpredsum2, fig.cap ="(ref:postpredsum2)", message = FALSE----
df_recall_ext <- df_recall %>%
  bind_rows(tibble(
    set_size = rep(c(3, 5, 7), 23),
    c_set_size = set_size -
      mean(df_recall$set_size),
    correct = 0
  ))
# nicer label for the facets:
set_size <- paste("set size", 2:8) %>%
  setNames(-3:3)
pp_check(fit_recall,
  type = "stat_grouped",
  stat = "mean",
  group = "c_set_size",
  newdata = df_recall_ext,
  facet_args = list(
    ncol = 1, scales = "fixed",
    labeller = as_labeller(set_size)
  ),
  binwidth = 0.02
)


## A simple linear regression: Power posing and testosterone.


## ---------------------------------------
data("df_powerpose")
head(df_powerpose)


## A first linear regression: Revisiting attentional load effect on pupil size.


## Log-normal model: Revisiting the effect of trial on  response times.


## Logistic regression: Revisiting the effect of set size on free recall.


## Red is the sexiest color.


## ---------------------------------------
data("df_red")
head(df_red)

